@@ -1,11 +1,9 @@
 package Mock::Populate;
-BEGIN {
-  $Mock::Populate::AUTHORITY = 'cpan:GENE';
-}
+our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Mock data creation
 
-our $VERSION = '0.0901';
+our $VERSION = '0.0902';
 
 use strict;
 use warnings;
@@ -115,7 +113,7 @@ sub time_ranger {
         if ($args{stamp}) {
             # In HH:MM::SS format.
             my $time = scalar localtime($start_time + $offset);
-            push @results, (split / /, $time)[3];
+            push @results, (split / /, $time)[4];
         }
         else {
             # As a number of seconds from the "epoc."
@@ -392,7 +390,7 @@ Mock::Populate - Mock data creation
 
 =head1 VERSION
 
-version 0.0901
+version 0.0902
 
 =head1 SYNOPSIS
 
@@ -636,7 +634,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Gene Boggs.
+This software is copyright (c) 2015 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
